From fd36a9ebb52c166813c1192e9a7ada6ba3ac8d1c Mon Sep 17 00:00:00 2001
From: Andreas Rammhold <andreas@rammhold.de>
Date: Thu, 4 Mar 2021 11:58:11 +0100
Subject: [PATCH] nixos/switch-to-configuration: restart each service
 individually

I often observe the restart line to hang for *days* on all of my devices
without making any progress. There appears to be no way to figure out
what it is currently stuck restarting right now.

Given that restarting the services as a whole doesn't give us any
guarantees about the restart ordering anyway there is probably no point
in trying to restart all of them at the same time anyway.
---
 nixos/modules/system/activation/switch-to-configuration.pl | 5 ++++-
 1 file changed, 4 insertions(+), 1 deletion(-)

diff --git a/nixos/modules/system/activation/switch-to-configuration.pl b/nixos/modules/system/activation/switch-to-configuration.pl
index b82d69b3bb8..bd31869ed15 100644
--- a/nixos/modules/system/activation/switch-to-configuration.pl
+++ b/nixos/modules/system/activation/switch-to-configuration.pl
@@ -430,7 +430,10 @@ if (scalar(keys %unitsToReload) > 0) {
 # than stopped and started).
 if (scalar(keys %unitsToRestart) > 0) {
     print STDERR "restarting the following units: ", join(", ", sort(keys %unitsToRestart)), "\n";
-    system("@systemd@/bin/systemctl", "restart", "--", sort(keys %unitsToRestart)) == 0 or $res = 4;
+    for my $unit (sort(keys %unitsToRestart)) {
+        print STDERR "restarting the unit ", $unit, "\n";
+        system("@systemd@/bin/systemctl", "restart", "--", $unit) == 0 or $res = 4;
+    }
     unlink($restartListFile);
 }
 
-- 
2.30.1

